==> fwl_calliope-25.3.14.tar.gz: fwl_calliope-25.3.14/README.md <==
[![Tests for CALLIOPE](https://github.com/FormingWorlds/CALLIOPE/actions/workflows/tests.yaml/badge.svg)](https://github.com/FormingWorlds/CALLIOPE/actions/workflows/tests.yaml)
[![Documentation Status](https://readthedocs.org/projects/fwl-calliope/badge/?version=latest)](https://fwl-calliope.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

# CALLIOPE

Numerical model for the equilibrium outgassing of volatiles from a magma ocean.

Named after the [Greek muse of eloquence and epic poetry](https://en.wikipedia.org/wiki/Calliope).
Prounounced: *kal-IGH-uh-pee*.

## Documentation
https://fwl-calliope.readthedocs.io/en/latest/

## Contributors
| Name  | Email address |
| -     | -             |
Harrison Nicholls       | harrison.nicholls[at]physics.ox.ac.uk |
Dan J. Bower            | dbower[at]ethz.ch |
Tim Lichtenberg         | tim.lichtenberg[at]rug.nl |
Laurent Soucasse        | l.soucasse[at]esciencecenter.nl |
Stef Smeets             | s.smeets[at]esciencecenter.nl |

## Installation

Simply run `pip install -e .` in this folder and `calliope` will be added to your Python environment.

## Citations

Publications using this code should cite the following articles:

* Nicholls et al., (submitted to JGR: planets)
* https://www.sciencedirect.com/science/article/pii/S0012821X22005301
* https://www.sciencedirect.com/science/article/pii/S0009254101004144
* https://doi.org/10.1016/j.epsl.2021.117255
* https://academic.oup.com/petrology/article/36/6/1607/1493308
* https://www.sciencedirect.com/science/article/pii/S0016703722004896
* https://www.sciencedirect.com/science/article/pii/S0016703713001841
* https://www.sciencedirect.com/science/article/pii/S0016703715004391
* JANAF tables

==> fwl_calliope-25.5.4.tar.gz: fwl_calliope-25.5.4/README.md <==
[![Tests for CALLIOPE](https://github.com/FormingWorlds/CALLIOPE/actions/workflows/tests.yaml/badge.svg)](https://github.com/FormingWorlds/CALLIOPE/actions/workflows/tests.yaml)
[![Documentation Status](https://readthedocs.org/projects/fwl-calliope/badge/?version=latest)](https://fwl-calliope.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

# CALLIOPE

Numerical model for the equilibrium outgassing of volatiles from a magma ocean.

Named after the [Greek muse of eloquence and epic poetry](https://en.wikipedia.org/wiki/Calliope).
Prounounced: *kal-IGH-uh-pee*.

## Documentation
https://fwl-calliope.readthedocs.io/en/latest/

## Contributors
| Name  | Email address |
| -     | -             |
| Harrison Nicholls       | harrison.nicholls[at]physics.ox.ac.uk |
| Dan J. Bower            | dbower[at]ethz.ch |
| Tim Lichtenberg         | tim.lichtenberg[at]rug.nl |
| Laurent Soucasse        | l.soucasse[at]esciencecenter.nl |
| Stef Smeets             | s.smeets[at]esciencecenter.nl |

## Installation

Simply run `pip install -e .` in this folder and `calliope` will be added to your Python environment.

## Citations

Publications using this code should cite the following articles:

* [Nicholls et al. (2024)](https://agupubs.onlinelibrary.wiley.com/doi/10.1029/2024JE008576)
* [Nicholls et al. (2025)](https://academic.oup.com/mnras/article/536/3/2957/7926963?login=true)
* https://www.sciencedirect.com/science/article/pii/S0012821X22005301

Further references:

* https://www.sciencedirect.com/science/article/pii/S0009254101004144
* https://doi.org/10.1016/j.epsl.2021.117255
* https://academic.oup.com/petrology/article/36/6/1607/1493308
* https://www.sciencedirect.com/science/article/pii/S0016703722004896
* https://www.sciencedirect.com/science/article/pii/S0016703713001841
* https://www.sciencedirect.com/science/article/pii/S0016703715004391
* JANAF tables
